.. module:: tests.location

********
location
********

This module provides functions used to by :py:class:`pytest` to run tests against
the following objects:

- :py:class:`wwdtm.location.Location`
- :py:class:`wwdtm.location.LocationRecordings`
- :py:class:`wwdtm.location.LocationUtility`

test_location_recordings
========================

.. automodule:: tests.location.test_location_recordings
    :members:
    :undoc-members:

test_location_location
======================

.. automodule:: tests.location.test_location_location
    :members:
    :undoc-members:

test_location_utility
=====================

.. automodule:: tests.location.test_location_utility
    :members:
    :undoc-members:
